Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1510)

Unified Diff: ash/shell.cc

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/shell.cc
diff --git a/ash/shell.cc b/ash/shell.cc
index b758bd8cc97dd7a805292af778e4ff600a9aa192..7170d3025ce5553fe2f812a7b810bdf45866778a 100644
--- a/ash/shell.cc
+++ b/ash/shell.cc
@@ -98,8 +98,6 @@
#include "ash/wm/immersive_context_ash.h"
#include "ash/wm/immersive_handler_factory_ash.h"
#include "ash/wm/lock_state_controller.h"
-#include "ash/wm/maximize_mode/maximize_mode_controller.h"
-#include "ash/wm/maximize_mode/maximize_mode_window_manager.h"
#include "ash/wm/mru_window_tracker.h"
#include "ash/wm/overlay_event_filter.h"
#include "ash/wm/overview/window_selector_controller.h"
@@ -110,6 +108,8 @@
#include "ash/wm/system_gesture_event_filter.h"
#include "ash/wm/system_modal_container_event_filter.h"
#include "ash/wm/system_modal_container_layout_manager.h"
+#include "ash/wm/tablet_mode/tablet_mode_controller.h"
+#include "ash/wm/tablet_mode/tablet_mode_window_manager.h"
#include "ash/wm/toplevel_window_event_handler.h"
#include "ash/wm/video_detector.h"
#include "ash/wm/window_animations.h"
@@ -487,19 +487,19 @@ void Shell::UpdateAfterLoginStatusChange(LoginStatus status) {
}
}
-void Shell::NotifyMaximizeModeStarted() {
+void Shell::NotifyTabletModeStarted() {
for (auto& observer : shell_observers_)
- observer.OnMaximizeModeStarted();
+ observer.OnTabletModeStarted();
}
-void Shell::NotifyMaximizeModeEnding() {
+void Shell::NotifyTabletModeEnding() {
for (auto& observer : shell_observers_)
- observer.OnMaximizeModeEnding();
+ observer.OnTabletModeEnding();
}
-void Shell::NotifyMaximizeModeEnded() {
+void Shell::NotifyTabletModeEnded() {
for (auto& observer : shell_observers_)
- observer.OnMaximizeModeEnded();
+ observer.OnTabletModeEnded();
}
void Shell::NotifyOverviewModeStarting() {
@@ -647,14 +647,14 @@ Shell::~Shell() {
screen_orientation_controller_.reset();
screen_layout_observer_.reset();
// Destroy the virtual keyboard controller before the maximize mode controller
// since the latters destructor triggers events that the former is listening
// to but no longer cares about.
virtual_keyboard_controller_.reset();
// Destroy maximize mode controller early on since it has some observers which
// need to be removed.
- maximize_mode_controller_.reset();
+ tablet_mode_controller_.reset();
// Destroy the keyboard before closing the shelf, since it will invoke a shelf
// layout.
@@ -950,7 +950,7 @@ void Shell::Init(const ShellInitParams& init_params) {
}
accelerator_controller_ = shell_port_->CreateAcceleratorController();
- maximize_mode_controller_ = base::MakeUnique<MaximizeModeController>();
+ tablet_mode_controller_ = base::MakeUnique<TabletModeController>();
magnifier_key_scroll_handler_ = MagnifierKeyScroller::CreateHandler();
AddPreTargetHandler(magnifier_key_scroll_handler_.get());
@@ -647,14 +647,14 @@ Shell::~Shell() {
screen_orientation_controller_.reset();
screen_layout_observer_.reset();
- // Destroy the virtual keyboard controller before the maximize mode controller
+ // Destroy the virtual keyboard controller before the tablet mode controller
// since the latters destructor triggers events that the former is listening
// to but no longer cares about.
@@ -647,14 +647,14 @@ Shell::~Shell() {
// to but no longer cares about.
virtual_keyboard_controller_.reset();
- // Destroy maximize mode controller early on since it has some observers which
+ // Destroy tablet mode controller early on since it has some observers which
// need to be removed.

Powered by Google App Engine
This is Rietveld 408576698